==> darwin-shared-0.1.15.tar.gz: darwin-shared-0.1.15/darwin/utils/request.py <==
import json
from functools import partial
from google.appengine.api import urlfetch


POST = urlfetch.POST
GET = urlfetch.GET
PUT = urlfetch.PUT
DELETE = urlfetch.DELETE


class Response:

    def __init__(self, content, status, headers):
        self.content = content
        self.status = status
        self.headers= headers

    def contentJson(self):
        return json.loads(self.content)


class Request:

    @classmethod
    def fetch(cls, url, body=None, method=GET, headers=None, deadline=5, validateSSL=False, followRedirects=False):
        response = urlfetch.fetch(
            url=url,
            payload=body,
            method=method,
            headers=headers or {},
            validate_certificate=validateSSL,
            follow_redirects=followRedirects,
            deadline=deadline
        )
        return Response(
            headers=response.headers,
            content=response.content,
            status=response.status_code
        )

    @classmethod
    def fetchMulti(cls, urls, bodies=None, method=GET, headers=None, deadline=15, validateSSL=False, followRedirects=False):
        responses = []

        def handleResult(rpc, responses):
            response = rpc.get_result()
            responses.append(
                Response(
                    headers=response.headers,
                    content=response.content,
                    status=response.status_code
                )
            )

        rpcs = []
        for index, url in enumerate(urls):
            body = bodies[index] if bodies and type(bodies) == list else None
            rpc = urlfetch.create_rpc(deadline=deadline)
            rpc.callback = partial(handleResult, rpc, responses)
            urlfetch.make_fetch_call(
                rpc,
                url=url,
                payload=body,
                method=method,
                headers=headers or {},
                validate_certificate=validateSSL,
                follow_redirects=followRedirects
            )
            rpcs.append(rpc)

        for rpc in rpcs:
            rpc.wait()

        return responses

==> darwin-shared-0.2.21.tar.gz: darwin-shared-0.2.21/darwin/utils/request.py <==
from json import loads
from functools import partial
from google.appengine.api import urlfetch


POST = urlfetch.POST
GET = urlfetch.GET
PUT = urlfetch.PUT
DELETE = urlfetch.DELETE


class Response:

    def __init__(self, content, status, headers):
        self.content = content
        self.status = status
        self.headers= headers

    def contentJson(self):
        return loads(self.content)


class Request:

    @classmethod
    def fetch(cls, url, body=None, method=GET, headers=None, deadline=5, validateSSL=False, followRedirects=False):
        response = urlfetch.fetch(
            url=url,
            payload=body,
            method=method,
            headers=headers or {},
            validate_certificate=validateSSL,
            follow_redirects=followRedirects,
            deadline=deadline
        )
        return Response(
            headers=response.headers,
            content=response.content,
            status=response.status_code
        )

    @classmethod
    def fetchMulti(cls, urls, bodies=None, method=GET, headers=None, deadline=15, validateSSL=False, followRedirects=False):
        responses = []

        def handleResult(rpc, responses):
            response = rpc.get_result()
            responses.append(
                Response(
                    headers=response.headers,
                    content=response.content,
                    status=response.status_code
                )
            )

        rpcs = []
        for index, url in enumerate(urls):
            body = bodies[index] if bodies and type(bodies) == list else None
            rpc = urlfetch.create_rpc(deadline=deadline)
            rpc.callback = partial(handleResult, rpc, responses)
            urlfetch.make_fetch_call(
                rpc,
                url=url,
                payload=body,
                method=method,
                headers=headers or {},
                validate_certificate=validateSSL,
                follow_redirects=followRedirects
            )
            rpcs.append(rpc)

        for rpc in rpcs:
            rpc.wait()

        return responses
